# Abbreviator

Python Module to Abbreviate (product) names, using hyphenation provided by the [pyphen](https://pyphen.org/) package


## Example Usage

with `from abbreviate import sentence_shortener` use

```
sentence_shortener( "A verylong productname superdupermegafluxcompresses p2000", language=lang)
```

## UbiOps package

